===================
Buildroot overrides
===================

Python objects
==============

.. automodule:: bodhi.messages.schemas.buildroot_override
   :exclude-members: body_schema, __module__
   :members:
   :show-inheritance:
   :special-members:
   :undoc-members:


JSON schemas
============

.. include:: ../../generated/buildroot_override.rst
